@@ -1,7 +1,8 @@
 """Define a RainMachine controller class."""
-# pylint: disable=too-few-public-methods,too-many-instance-attributes
+from __future__ import annotations
+
 from datetime import datetime, timedelta
-from typing import Any, Awaitable, Callable, Dict, Optional
+from typing import Any, Awaitable, Callable
 
 from regenmaschine.api import API
 from regenmaschine.diagnostics import Diagnostics
@@ -22,16 +23,16 @@ class Controller:  # pylint: disable=too-many-instance-attributes
 
     def __init__(self, request: Callable[..., Awaitable[dict]]) -> None:
         """Initialize."""
-        self._access_token: Optional[str] = None
-        self._access_token_expiration: Optional[datetime] = None
+        self._access_token: str | None = None
+        self._access_token_expiration: datetime | None = None
         self._client_request = request
-        self._host: Optional[str] = None
-        self._ssl = True
-        self.api_version: Optional[str] = None
-        self.hardware_version: Optional[int] = None
-        self.mac: Optional[str] = None
-        self.name: Optional[str] = None
-        self.software_version: Optional[str] = None
+        self._host: str = ""
+        self._use_ssl = True
+        self.api_version: str = ""
+        self.hardware_version: int = 0
+        self.mac: str = ""
+        self.name: str = ""
+        self.software_version: str = ""
 
         # API endpoints:
         self.api = API(self._request)
@@ -45,15 +46,15 @@ class Controller:  # pylint: disable=too-many-instance-attributes
         self.zones = Zone(self._request)
 
     async def _request(
-        self, method: str, endpoint: str, **kwargs: Dict[str, Any]
-    ) -> Dict[str, Any]:
+        self, method: str, endpoint: str, **kwargs: dict[str, Any]
+    ) -> dict[str, Any]:
         """Wrap the generic request method to add access token, etc."""
         return await self._client_request(
             method,
             f"{self._host}/{endpoint}",
             access_token=self._access_token,
             access_token_expiration=self._access_token_expiration,
-            ssl=self._ssl,
+            use_ssl=self._use_ssl,
             **kwargs,
         )
 
@@ -62,13 +63,17 @@ class LocalController(Controller):
     """Define a controller accessed over the LAN."""
 
     def __init__(  # pylint: disable=too-many-arguments
-        self, request: Callable[..., Awaitable[dict]], host: str, port: int, ssl: bool
+        self,
+        request: Callable[..., Awaitable[dict]],
+        host: str,
+        port: int,
+        use_ssl: bool = True,
     ) -> None:
         """Initialize."""
         super().__init__(request)
 
         self._host = URL_BASE_LOCAL.format(host, port)
-        self._ssl = ssl
+        self._use_ssl = use_ssl
 
     async def login(self, password: str) -> None:
         """Authenticate against the device (locally)."""
